@@ -117,14 +117,18 @@ create_collection_with_secret (GkdSecretCreate *self, GkdSecretSecret *master)
 		return FALSE;
 	}
 
+	service = gkd_secret_prompt_get_service (GKD_SECRET_PROMPT (self));
+
 	if (self->alias) {
 		if (!gkd_secret_util_parse_path (self->result_path, &identifier, NULL))
 			g_assert_not_reached ();
-		service = gkd_secret_prompt_get_service (GKD_SECRET_PROMPT (self));
 		gkd_secret_service_set_alias (service, self->alias, identifier);
 		g_free (identifier);
 	}
 
+	/* Notify the callers that a collection was created */
+	gkd_secret_service_emit_collection_created (service, self->result_path);
+
 	return TRUE;
 }
 
@@ -392,11 +396,15 @@ GkdSecretCreate*
 gkd_secret_create_new (GkdSecretService *service, const gchar *caller,
                        GckAttributes *attrs, const gchar *alias)
 {
+	const gchar *prompter_name;
+
+	prompter_name = g_getenv ("GNOME_KEYRING_TEST_PROMPTER");
 	return g_object_new (GKD_SECRET_TYPE_CREATE,
 	                     "service", service,
 	                     "caller", caller,
 	                     "pkcs11-attributes", attrs,
 	                     "alias", alias,
+	                     "bus-name", prompter_name,
 	                     NULL);
 }
 
