@@ -28,8 +28,6 @@
 
 #include "pkcs11/pkcs11.h"
 
-#include "egg/egg-bytes.h"
-
 CK_RV                 gkm_attribute_get_bool                           (CK_ATTRIBUTE_PTR attr,
                                                                         gboolean *value);
 
@@ -70,7 +68,7 @@ CK_RV                 gkm_attribute_set_data                           (CK_ATTRI
                                                                         gsize n_value);
 
 CK_RV                 gkm_attribute_set_bytes                          (CK_ATTRIBUTE_PTR attr,
-                                                                        EggBytes *value);
+                                                                        GBytes *value);
 
 CK_RV                 gkm_attribute_set_mpi                            (CK_ATTRIBUTE_PTR attr,
                                                                         gcry_mpi_t mpi);
