@@ -30,50 +30,49 @@
 #include "gkm-data-types.h"
 
 #include "egg/egg-asn1x.h"
-#include "egg/egg-bytes.h"
 
 /* -----------------------------------------------------------------------------
  * PRIVATE KEYS
  */
 
-GkmDataResult      gkm_data_der_read_private_key_rsa         (EggBytes *data,
+GkmDataResult      gkm_data_der_read_private_key_rsa         (GBytes *data,
                                                               gcry_sexp_t *s_key);
 
-GkmDataResult      gkm_data_der_read_private_key_dsa         (EggBytes *data,
+GkmDataResult      gkm_data_der_read_private_key_dsa         (GBytes *data,
                                                               gcry_sexp_t *s_key);
 
-GkmDataResult      gkm_data_der_read_private_key_dsa_parts   (EggBytes *keydata,
-                                                              EggBytes *params,
+GkmDataResult      gkm_data_der_read_private_key_dsa_parts   (GBytes *keydata,
+                                                              GBytes *params,
                                                               gcry_sexp_t *s_key);
 
-GkmDataResult      gkm_data_der_read_private_key             (EggBytes *data,
+GkmDataResult      gkm_data_der_read_private_key             (GBytes *data,
                                                               gcry_sexp_t *s_key);
 
-GkmDataResult      gkm_data_der_read_private_pkcs8           (EggBytes *data,
+GkmDataResult      gkm_data_der_read_private_pkcs8           (GBytes *data,
                                                               const gchar *password,
                                                               gsize n_password,
                                                               gcry_sexp_t *s_key);
 
-GkmDataResult      gkm_data_der_read_private_pkcs8_plain     (EggBytes *data,
+GkmDataResult      gkm_data_der_read_private_pkcs8_plain     (GBytes *data,
                                                               gcry_sexp_t *s_key);
 
-GkmDataResult      gkm_data_der_read_private_pkcs8_crypted   (EggBytes *data,
+GkmDataResult      gkm_data_der_read_private_pkcs8_crypted   (GBytes *data,
                                                               const gchar *password, gsize n_password,
                                                               gcry_sexp_t *s_key);
 
-EggBytes *         gkm_data_der_write_private_key_rsa        (gcry_sexp_t s_key);
+GBytes *           gkm_data_der_write_private_key_rsa        (gcry_sexp_t s_key);
 
-EggBytes *         gkm_data_der_write_private_key_dsa        (gcry_sexp_t s_key);
+GBytes *           gkm_data_der_write_private_key_dsa        (gcry_sexp_t s_key);
 
-EggBytes *         gkm_data_der_write_private_key_dsa_part   (gcry_sexp_t skey);
+GBytes *           gkm_data_der_write_private_key_dsa_part   (gcry_sexp_t skey);
 
-EggBytes *         gkm_data_der_write_private_key_dsa_params (gcry_sexp_t skey);
+GBytes *           gkm_data_der_write_private_key_dsa_params (gcry_sexp_t skey);
 
-EggBytes *         gkm_data_der_write_private_key            (gcry_sexp_t s_key);
+GBytes *           gkm_data_der_write_private_key            (gcry_sexp_t s_key);
 
-EggBytes *         gkm_data_der_write_private_pkcs8_plain    (gcry_sexp_t skey);
+GBytes *           gkm_data_der_write_private_pkcs8_plain    (gcry_sexp_t skey);
 
-EggBytes *         gkm_data_der_write_private_pkcs8_crypted  (gcry_sexp_t skey,
+GBytes *           gkm_data_der_write_private_pkcs8_crypted  (gcry_sexp_t skey,
                                                               const gchar *password,
                                                               gsize n_password);
 
@@ -81,46 +80,46 @@ EggBytes *         gkm_data_der_write_private_pkcs8_crypted  (gcry_sexp_t skey,
  * PUBLIC KEYS
  */
 
-GkmDataResult      gkm_data_der_read_public_key_rsa        (EggBytes *data,
+GkmDataResult      gkm_data_der_read_public_key_rsa        (GBytes *data,
                                                             gcry_sexp_t *s_key);
 
-GkmDataResult      gkm_data_der_read_public_key_dsa        (EggBytes *data,
+GkmDataResult      gkm_data_der_read_public_key_dsa        (GBytes *data,
                                                             gcry_sexp_t *s_key);
 
-GkmDataResult      gkm_data_der_read_public_key_dsa_parts  (EggBytes *keydata,
-                                                            EggBytes *params,
+GkmDataResult      gkm_data_der_read_public_key_dsa_parts  (GBytes *keydata,
+                                                            GBytes *params,
                                                             gcry_sexp_t *s_key);
 
-GkmDataResult      gkm_data_der_read_public_key            (EggBytes *data,
+GkmDataResult      gkm_data_der_read_public_key            (GBytes *data,
                                                             gcry_sexp_t *s_key);
 
-GkmDataResult      gkm_data_der_read_public_key_info       (EggBytes *data,
+GkmDataResult      gkm_data_der_read_public_key_info       (GBytes *data,
                                                             gcry_sexp_t *s_key);
 
-EggBytes *         gkm_data_der_write_public_key_rsa       (gcry_sexp_t s_key);
+GBytes *           gkm_data_der_write_public_key_rsa       (gcry_sexp_t s_key);
 
-EggBytes *         gkm_data_der_write_public_key_dsa       (gcry_sexp_t s_key);
+GBytes *           gkm_data_der_write_public_key_dsa       (gcry_sexp_t s_key);
 
-EggBytes *         gkm_data_der_write_public_key           (gcry_sexp_t s_key);
+GBytes *           gkm_data_der_write_public_key           (gcry_sexp_t s_key);
 
 
 /* -----------------------------------------------------------------------------
  * CERTIFICATES
  */
 
-GkmDataResult      gkm_data_der_read_certificate           (EggBytes *data,
+GkmDataResult      gkm_data_der_read_certificate           (GBytes *data,
                                                             GNode **asn1);
 
-GkmDataResult      gkm_data_der_read_basic_constraints     (EggBytes *data,
+GkmDataResult      gkm_data_der_read_basic_constraints     (GBytes *data,
                                                             gboolean *is_ca,
                                                             gint *path_len);
 
-GkmDataResult      gkm_data_der_read_key_usage             (EggBytes *data,
+GkmDataResult      gkm_data_der_read_key_usage             (GBytes *data,
                                                             gulong *key_usage);
 
-GkmDataResult      gkm_data_der_read_enhanced_usage        (EggBytes *data,
+GkmDataResult      gkm_data_der_read_enhanced_usage        (GBytes *data,
                                                             GQuark **oids);
 
-EggBytes *         gkm_data_der_write_certificate          (GNode *asn1);
+GBytes *           gkm_data_der_write_certificate          (GNode *asn1);
 
 #endif /*GKRPKIXDER_H_*/
