@@ -144,7 +144,9 @@ test_key_to_public (Test *test, gconstpointer unused)
 int
 main (int argc, char **argv)
 {
+#if !GLIB_CHECK_VERSION(2,35,0)
 	g_type_init ();
+#endif
 	g_test_init (&argc, &argv, NULL);
 
 	g_test_add ("/gkm/sexp/parse_key", Test, NULL, setup, test_parse_key, teardown);
