@@ -476,7 +476,9 @@ test_match_wrong_hashed (void)
 int
 main (int argc, char **argv)
 {
+#if !GLIB_CHECK_VERSION(2,35,0)
 	g_type_init ();
+#endif
 	g_test_init (&argc, &argv, NULL);
 
 	g_test_add_func ("/secret-store/fields/new", test_new);
