@@ -34,6 +34,8 @@
 
 #include "gkm/gkm-assertion.h"
 #include "gkm/gkm-certificate.h"
+#define DEBUG_FLAG GKM_DEBUG_STORAGE
+#include "gkm/gkm-debug.h"
 #include "gkm/gkm-file-tracker.h"
 #include "gkm/gkm-serializable.h"
 #include "gkm/gkm-transaction.h"
@@ -203,7 +205,7 @@ file_load (GkmFileTracker *tracker, const gchar *path, GkmXdgModule *self)
 	GkmManager *manager;
 	gboolean added = FALSE;
 	GError *error = NULL;
-	EggBytes *bytes;
+	GBytes *bytes;
 	GType type;
 	guchar *data;
 	gsize n_data;
@@ -220,7 +222,7 @@ file_load (GkmFileTracker *tracker, const gchar *path, GkmXdgModule *self)
 		/* Figure out what type of object we're dealing with */
 		type = type_from_path (path);
 		if (type == 0) {
-			g_message ("don't know how to load file in key store: %s", path);
+			gkm_debug ("don't know how to load file in key store: %s", path);
 			return;
 		}
 
@@ -246,7 +248,7 @@ file_load (GkmFileTracker *tracker, const gchar *path, GkmXdgModule *self)
 		return;
 	}
 
-	bytes = egg_bytes_new_take (data, n_data);
+	bytes = g_bytes_new_take (data, n_data);
 
 	/* And load the data into it */
 	if (gkm_serializable_load (GKM_SERIALIZABLE (object), NULL, bytes)) {
@@ -262,7 +264,7 @@ file_load (GkmFileTracker *tracker, const gchar *path, GkmXdgModule *self)
 		}
 	}
 
-	egg_bytes_unref (bytes);
+	g_bytes_unref (bytes);
 	g_object_unref (object);
 }
 
@@ -283,16 +285,16 @@ static gchar*
 name_for_subject (gconstpointer data,
                   gsize n_data)
 {
-	EggBytes *subject;
+	GBytes *subject;
 	GNode *asn;
 	gchar *name;
 
 	g_assert (data != NULL);
 
-	subject = egg_bytes_new (data, n_data);
+	subject = g_bytes_new (data, n_data);
 	asn = egg_asn1x_create_and_decode (pkix_asn1_tab, "Name", subject);
 	g_return_val_if_fail (asn != NULL, NULL);
-	egg_bytes_unref (subject);
+	g_bytes_unref (subject);
 
 	name = egg_dn_read_part (egg_asn1x_node (asn, "rdnSequence", NULL), "CN");
 	egg_asn1x_destroy (asn);
@@ -439,7 +441,7 @@ gkm_xdg_module_real_store_token_object (GkmModule *module, GkmTransaction *trans
 {
 	GkmXdgModule *self = GKM_XDG_MODULE (module);
 	const gchar *filename;
-	EggBytes *bytes;
+	GBytes *bytes;
 	GkmTrust *trust;
 
 	/* Always serialize the trust object for each assertion */
@@ -468,9 +470,9 @@ gkm_xdg_module_real_store_token_object (GkmModule *module, GkmTransaction *trans
 	g_return_if_fail (g_hash_table_lookup (self->objects_by_path, filename) == object);
 
 	gkm_transaction_write_file (transaction, filename,
-	                            egg_bytes_get_data (bytes),
-	                            egg_bytes_get_size (bytes));
-	egg_bytes_unref (bytes);
+	                            g_bytes_get_data (bytes, NULL),
+	                            g_bytes_get_size (bytes));
+	g_bytes_unref (bytes);
 }
 
 static void
